Linux Documentation
 help / color / mirror / Atom feed
From: "Gustavo Kenji Mendonça Kaneko" <kaneko.dev@pm.me>
To: dri-devel@lists.freedesktop.org
Cc: airlied@gmail.com, simona@ffwll.ch, alexander.deucher@amd.com,
	christian.koenig@amd.com, harry.wentland@amd.com, corbet@lwn.net,
	amd-gfx@lists.freedesktop.org, linux-doc@vger.kernel.org,
	linux-kernel@vger.kernel.org,
	"Gustavo Kenji Mendonça Kaneko" <kaneko.dev@pm.me>
Subject: [PATCH 2/2] drm/amd/display: rename timeout_occured to timeout_occurred
Date: Sun, 31 May 2026 04:59:09 +0000	[thread overview]
Message-ID: <20260531045852.41849-2-kaneko.dev@pm.me> (raw)
In-Reply-To: <20260531045852.41849-1-kaneko.dev@pm.me>

Fix spelling mistake in struct dmub_timeout_info field name.
Rename 'timeout_occured' to 'timeout_occurred' and update
all references in dc_dmub_srv.c accordingly.

Signed-off-by: Gustavo Kenji Mendonça Kaneko <kaneko.dev@pm.me>
---
 drivers/gpu/drm/amd/display/dc/dc_dmub_srv.c | 4 ++--
 drivers/gpu/drm/amd/display/dmub/dmub_srv.h  | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/dc/dc_dmub_srv.c b/drivers/gpu/drm/amd/display/dc/dc_dmub_srv.c
index 79c8b4cab053..4b47172a71c0 100644
--- a/drivers/gpu/drm/amd/display/dc/dc_dmub_srv.c
+++ b/drivers/gpu/drm/amd/display/dc/dc_dmub_srv.c
@@ -285,8 +285,8 @@ bool dc_dmub_srv_wait_for_idle(struct dc_dmub_srv *dc_dmub_srv,
 
 		if (status != DMUB_STATUS_OK) {
 			DC_LOG_DEBUG("No reply for DMUB command: status=%d\n", status);
-			if (!dmub->debug.timeout_info.timeout_occured) {
-				dmub->debug.timeout_info.timeout_occured = true;
+			if (!dmub->debug.timeout_info.timeout_occurred) {
+				dmub->debug.timeout_info.timeout_occurred = true;
 				if (cmd_list)
 					dmub->debug.timeout_info.timeout_cmd = *cmd_list;
 				dmub->debug.timeout_info.timestamp = dm_get_timestamp(dc_dmub_srv->ctx);
diff --git a/drivers/gpu/drm/amd/display/dmub/dmub_srv.h b/drivers/gpu/drm/amd/display/dmub/dmub_srv.h
index c18ff8f00bb8..33fcda687a86 100644
--- a/drivers/gpu/drm/amd/display/dmub/dmub_srv.h
+++ b/drivers/gpu/drm/amd/display/dmub/dmub_srv.h
@@ -355,11 +355,11 @@ struct dmub_srv_hw_params {
 
 /**
  * struct dmub_srv_debug - Debug info for dmub_srv
  * @timeout_occured: Indicates a timeout occured on any message from driver to dmub
  * @timeout_cmd: first cmd sent from driver that timed out - subsequent timeouts are not stored
  */
 struct dmub_timeout_info {
-	bool timeout_occured;
+	bool timeout_occurred;
 	union dmub_rb_cmd timeout_cmd;
 	unsigned long long timestamp;
 };
@@ -355,11 +355,11 @@ struct dmub_srv_hw_params {
 /**
  * struct dmub_srv_debug - Debug info for dmub_srv
- * @timeout_occured: Indicates a timeout occured on any message from driver to dmub
+ * @timeout_occurred: Indicates a timeout occurred on any message from driver to dmub
  * @timeout_cmd: first cmd sent from driver that timed out - subsequent timeouts are not stored
  */
-- 
2.54.0



      reply	other threads:[~2026-05-31  4:59 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-05-31  4:59 [PATCH 1/2] drm: fix spelling mistakes in comments and documentation Gustavo Kenji Mendonça Kaneko
2026-05-31  4:59 ` Gustavo Kenji Mendonça Kaneko [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260531045852.41849-2-kaneko.dev@pm.me \
    --to=kaneko.dev@pm.me \
    --cc=airlied@gmail.com \
    --cc=alexander.deucher@amd.com \
    --cc=amd-gfx@lists.freedesktop.org \
    --cc=christian.koenig@amd.com \
    --cc=corbet@lwn.net \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=harry.wentland@amd.com \
    --cc=linux-doc@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=simona@ffwll.ch \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox